summaryrefslogtreecommitdiffstats
path: root/chromium/chrome/browser/ui/webui/webui_load_timer.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/chrome/browser/ui/webui/webui_load_timer.h')
-rw-r--r--chromium/chrome/browser/ui/webui/webui_load_timer.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/chromium/chrome/browser/ui/webui/webui_load_timer.h b/chromium/chrome/browser/ui/webui/webui_load_timer.h
index 5474b646af3..83e089c370a 100644
--- a/chromium/chrome/browser/ui/webui/webui_load_timer.h
+++ b/chromium/chrome/browser/ui/webui/webui_load_timer.h
@@ -20,7 +20,7 @@ class WebuiLoadTimer : public content::WebContentsObserver {
public:
// Load times are reported to UMA using the provided strings which
// must not be empty.
// * |document_initial_load_uma_id| - corresponds to DocumentLoadedInFrame
// * |document_load_completed_uma_id| - corresponds to
// DocumentOnLoadCompletedInMainFrame
WebuiLoadTimer(content::WebContents* web_contents,
@@ -31,8 +31,7 @@ class WebuiLoadTimer : public content::WebContentsObserver {
// WebContentsObserver
void DidStartNavigation(
content::NavigationHandle* navigation_handle) override;
- void DocumentLoadedInFrame(
- content::RenderFrameHost* render_frame_host) override;
+ void DOMContentLoaded(content::RenderFrameHost* render_frame_host) override;
void DocumentOnLoadCompletedInMainFrame() override;
private:
@@ -20,7 +20,7 @@ class WebuiLoadTimer : public content::WebContentsObserver {
// Load times are reported to UMA using the provided strings which
// must not be empty.
- // * |document_initial_load_uma_id| - corresponds to DocumentLoadedInFrame
+ // * |document_initial_load_uma_id| - corresponds to DOMContentLoaded
// * |document_load_completed_uma_id| - corresponds to
// DocumentOnLoadCompletedInMainFrame